#!/bin/bash

error() {
	printf "%s\n" "$@" >&2
	exit 1
}

cd "$(dirname "$0")" || error "cd test dir"

# option to regenerate output we compare with
# use with care if podman_start output changed
# or after confirming new tests work
REGENERATE="${REGENERATE:-}"

[ -z "$REGENERATE" ] || rm -f podman/*/output.*

check_output() {
	local output="$1"
	shift
	local cmd=( "$@" )

	echo "${cmd[*]}"

	if [ -n "$REGENERATE" ]; then
		"${cmd[@]}" > "$d/output.$output"
	else
		diff -u "$d/output.$output" <("${cmd[@]}") \
			|| error "'${cmd[*]}' produced different output than expected"
	fi

}


# verify dry run mode, always
for d in podman/*; do
	[ -d "$d" ] || continue
	check_output all ../podman/podman_start -n -c "$d" -a
	for f in "$d/"*.conf; do
		b=$(basename "$f" .conf)
		check_output "$b" ../podman/podman_start -n -c "$d" "$b"
	done
done

# if podman is available also run some containers
command -v podman > /dev/null || exit 0

# setup test requirements
export TMPDIR=$(mktemp -d /tmp/atmark-x2-base.podman.XXXXXX) \
	|| error "Could not create temp dir"
trap "rm -rf '$TMPDIR'" EXIT
mkdir "$TMPDIR/test space"
echo foo > "$TMPDIR/test space/foo"
mkdir "$TMPDIR/test"
echo bar > "$TMPDIR/test/bar"

for d in podman/run_*; do
	for f in "$d"/*.conf; do
		b=$(basename "$f" .conf)
		../podman/podman_start -v -c "$d" "$b" \
			|| error "podman_start -c $d $b failed"
		timeout 10s podman wait "$b" \
			|| error "container $b ($d) didn't stop within timeout?"
		check_output "run_$b" podman logs "$b"
		podman rm "$b"
	done
done

